@@ -1,11 +1,27 @@
 # Paranoid -- Paranoia support for safer programs
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# $Id: lib/Paranoid.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 #
-# $Id: lib/Paranoid.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
+# (c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+# (tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
+# This software is free software.  Similar to Perl, you can redistribute it
+# and/or modify it under the terms of either:
 #
-#    This software is licensed under the same terms as Perl, itself.
-#    Please see http://dev.perl.org/licenses/ for more information.
+#   a)     the GNU General Public License
+#          <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+#          Free Software Foundation <http://www.fsf.org/>; either version 1
+#          <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+#          <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+#   b)     the Artistic License 2.0
+#          <https://opensource.org/licenses/Artistic-2.0>,
+#
+# subject to the following additional term:  No trademark rights to
+# "Paranoid" have been or are conveyed under any of the above licenses.
+# However, "Paranoid" may be used fairly to describe this unmodified
+# software, in good faith, but not as a trademark.
+#
+# (c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+# (tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 #
 #####################################################################
 
@@ -24,7 +40,7 @@ use warnings;
 use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use base qw(Exporter);
 
-($VERSION) = ( q$Revision: 2.04 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.08 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT      = qw(psecureEnv);
 @EXPORT_OK   = ( @EXPORT, qw(PTRUE_ZERO) );
@@ -100,7 +116,7 @@ Paranoid - Paranoia support for safer programs
 
 =head1 VERSION
 
-$Id: lib/Paranoid.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
+$Id: lib/Paranoid.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -125,6 +141,18 @@ This module does provide one function meant to secure your environment
 enough to satisfy taint-enabled programs, and as a container which holds the 
 last reported error from any code in the Paranoid framework.
 
+=head1 IMPORT LISTS
+
+This module exports the following symbols by default:
+
+    psecureEnv
+
+The following specialized import lists also exist:
+
+    List        Members
+    --------------------------------------------------------
+    all         @defaults PTRUE_ZERO
+
 =head1 SUBROUTINES/METHODS
 
 =head2 psecureEnv
@@ -181,6 +209,14 @@ L<Paranoid::Data>: Misc. data manipulation functions
 
 =item o
 
+L<Paranoid::Data::AVLTree>: AVL-Balanced Tree Class
+
+=item o
+
+L<Paranoid::Data::AVLTree::AVLNode>: AVL-Balanced Tree Node Class
+
+=item o
+
 L<Paranoid::Debug>: Command-line debugging framework and functions
 
 =item o
@@ -253,8 +289,22 @@ Arthur Corliss (corliss@digitalmages.com)
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is licensed under the same terms as Perl, itself. 
-Please see http://dev.perl.org/licenses/ for more information.
+This software is free software.  Similar to Perl, you can redistribute it
+and/or modify it under the terms of either:
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+  a)     the GNU General Public License
+         <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+         Free Software Foundation <http://www.fsf.org/>; either version 1
+         <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+         <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+  b)     the Artistic License 2.0
+         <https://opensource.org/licenses/Artistic-2.0>,
+
+subject to the following additional term:  No trademark rights to
+"Paranoid" have been or are conveyed under any of the above licenses.
+However, "Paranoid" may be used fairly to describe this unmodified
+software, in good faith, but not as a trademark.
+
+(c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+(tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 
