@@ -1,11 +1,25 @@
 # Paranoid::Args -- Command-line argument parsing functions
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# $Id: lib/Paranoid/Args.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 #
-# $Id: lib/Paranoid/Args.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+# This software is free software.  Similar to Perl, you can redistribute it
+# and/or modify it under the terms of either:
 #
-#    This software is licensed under the same terms as Perl, itself.
-#    Please see http://dev.perl.org/licenses/ for more information.
+#   a)     the GNU General Public License
+#          <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+#          Free Software Foundation <http://www.fsf.org/>; either version 1
+#          <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+#          <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+#   b)     the Artistic License 2.0
+#          <https://opensource.org/licenses/Artistic-2.0>,
+#
+# subject to the following additional term:  No trademark rights to
+# "Paranoid" have been or are conveyed under any of the above licenses.
+# However, "Paranoid" may be used fairly to describe this unmodified
+# software, in good faith, but not as a trademark.
+#
+# (c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+# (tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 #
 #####################################################################
 
@@ -26,11 +40,34 @@ use base qw(Exporter);
 use Paranoid;
 use Paranoid::Debug qw(:all);
 
-($VERSION) = ( q$Revision: 2.03 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.08 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT      = qw(parseArgs);
-@EXPORT_OK   = @EXPORT;
-%EXPORT_TAGS = ( all => [@EXPORT_OK], );
+@EXPORT_OK   = ( @EXPORT, qw(PA_DEBUG PA_VERBOSE PA_HELP PA_VERSION) );
+%EXPORT_TAGS = (
+    all      => [@EXPORT_OK],
+    template => [qw(PA_DEBUG PA_VERBOSE PA_HELP PA_VERSION)],
+    );
+
+# I know, this really doesn't protect the contents...
+use constant PA_DEBUG => {
+    Short      => 'D',
+    Long       => 'debug',
+    CountShort => 1,
+    };
+use constant PA_VERBOSE => {
+    Short      => 'v',
+    Long       => 'verbose',
+    CountShort => 1,
+    };
+use constant PA_HELP => {
+    Short => 'h',
+    Long  => 'help',
+    };
+use constant PA_VERSION => {
+    Short => 'V',
+    Long  => 'version',
+    };
 
 #####################################################################
 #
@@ -83,6 +120,19 @@ use Paranoid::Debug qw(:all);
         # Returns:  Contents of @errors
         # Usage:    @errors = listErrors();
 
+        my ( %messages, $n, @indices );
+
+        # Filter out redundant messages
+        $n = 0;
+        foreach (@errors) {
+            $messages{$_}++;
+            push @indices, $n if $messages{$_} > 1;
+            $n++;
+        }
+        foreach ( sort { $b <=> $a } @indices ) {
+            splice @errors, $_, 1;
+        }
+
         return @errors;
     }
 
@@ -182,7 +232,7 @@ sub _tLint {
     $oname = $$tref{Name};
 
     # Make sure a short or long option is declared
-    if ( $oname eq 'undef/undef' ) {
+    if ( !defined $oname ) {
         _pushErrors('No short or long option name declared');
         $rv = 0;
     }
@@ -272,6 +322,7 @@ sub _tLint {
     # Make sure CountShort is enabled only for those with a template of ''
     # or '$'
     if ($rv) {
+
         if ( $$tref{CountShort} ) {
             unless ( $$tref{Template} =~ /^\$?$/sm ) {
                 _pushErrors( "Option $oname has CountShort set but with an "
@@ -561,15 +612,29 @@ sub parseArgs (\@\%;\@) {
             %$_,
             };
 
-        # Create the short/long option for error-reporting purposes
-        $oname =
-              ( defined $$tref{Short} ? $$tref{Short} : 'undef' ) . '/'
-            . ( defined $$tref{Long}  ? $$tref{Long}  : 'undef' );
-        $$tref{Name} = $oname;
+        # Set AllOptions for error message reporting
+        $$tref{Name} =
+               defined $$tref{Short}
+            && defined $$tref{Long} ? "-$$tref{Short}/--$$tref{Long}"
+            : defined $$tref{Short} ? "-$$tref{Short}"
+            : defined $$tref{Long}  ? "--$$tref{Long}"
+            :                         undef;
 
         # Initialize our usage counter
         $$tref{Count} = 0;
 
+        # Anything that has CountShort enabled implies Multiple/CanBundle
+        # and a template of '$'
+        if ( $$tref{CountShort} ) {
+            $$tref{CanBundle} = $$tref{Multiple} = 1;
+            $$tref{Template} = '$' if defined $$tref{Long};
+        }
+
+        # Anything that has a Short option and a template of '$' or ''
+        # implies CanBundle
+        $$tref{CanBundle} = 1
+            if defined $$tref{Short} and $$tref{Template} eq '';
+
         # We'll associate both the long and short options to the same hash
         # to make sure that we count/collect everything appropriately.
         #
@@ -699,7 +764,8 @@ sub parseArgs (\@\%;\@) {
                             # Check if we've call this more than once
                             if ( not $$tref{Multiple}
                                 and $$tref{Count} > 0 ) {
-                                _pushErrors( "Option -$_ is only allowed "
+                                _pushErrors(
+                                    "Option $$tref{Name} is only allowed "
                                         . 'to be used once' );
                                 $rv = 0;
                                 next;
@@ -771,7 +837,7 @@ sub parseArgs (\@\%;\@) {
                         # Check if we've call this more than once
                         if ( not $$tref{Multiple} and $$tref{Count} > 0 ) {
                             _pushErrors(
-                                "Option --$_ is only allowed to be used once"
+                                "Option $$tref{Name} is only allowed to be used once"
                                 );
                             $rv = 0;
                             next;
@@ -819,7 +885,7 @@ sub parseArgs (\@\%;\@) {
             $regex = '(?:' . join( '|', @{ $$tref{ExclusiveOf} } ) . ')';
             if ( grep /^$regex$/sm, @tmp ) {
                 _pushErrors(
-                    "$_ cannot be called with the following options: "
+                    "$$tref{Name} cannot be called with the following options: "
                         . join ', ',
                     @{ $$tref{ExclusiveOf} } );
                 $rv = 0;
@@ -830,7 +896,7 @@ sub parseArgs (\@\%;\@) {
         foreach $regex ( @{ $$tref{AccompaniedBy} } ) {
             unless ( grep /^\Q$regex\E$/sm, @tmp ) {
                 _pushErrors(
-                    "$_ must be called with the following options: "
+                    "$$tref{Name} must be called with the following options: "
                         . join ', ',
                     @{ $$tref{AccompaniedBy} } );
                 $rv = 0;
@@ -857,7 +923,7 @@ Paranoid::Args - Command-line argument parsing functions
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Args.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+$Id: lib/Paranoid/Args.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -882,6 +948,19 @@ when it comes to this particular task.
 The primary focus of this module is validation, with the secondary focus being
 preservation of context.
 
+=head1 IMPORT LISTS
+
+This module exports the following symbols by default:
+
+    parseArgs
+
+The following specialized import lists also exist:
+
+    List        Members
+    --------------------------------------------------------
+    template    PA_DEBUG PA_VERBOSE PA_HELP PA_VERSION
+    all         @defaults @template 
+
 =head2 VALIDATION
 
 When validating the use of options and arguments we concern ourselves
@@ -1073,8 +1152,7 @@ similar) forms:
   --verbose 5
   --verbose=5
 
-If B<CountShort> was instead false you'd have to say '-v5' or '-v 5' instead 
-of '-vvvvv'.
+If B<CountShort> was instead false you'd have to say '-v 5' instead of '-vvvvv'.
 
 When the B<parseArgs> function is called the options hash passed to it would
 be populated with:
@@ -1089,6 +1167,29 @@ the long name you will be able to retrieve the cumulative value.
 
 The particulars of all key/value pairs in a template are documented below.
 
+B<NOTES:>  The default template is as follows:
+
+        {
+            Short         => undef,
+            Long          => undef,
+            Template      => '',
+            Multiple      => 0, 
+            ExclusiveOf   => [],
+            AccompaniedBy => [],
+            CanBundle     => 0,
+            CountShort    => 0,
+            Value         => undef,
+         };
+
+When creating your option templates you only need to specify those that differ
+from the defaults.  In addition, there's a few options that are also modified
+automatically for you.  If your template consists of a I<Short> option and has
+a template of I<''> then I<CanBundle> is automatically set to true.
+
+If I<CountShort> is enabled then I<Multiple> and I<CanBundle> is set to be
+true as well.  Additionally, if there is a I<Long> option, the I<Template> is
+set to I<'$'>.
+
 =head2 Short
 
 B<Short> refers to the form of the short option style (minus the normal
@@ -1231,6 +1332,42 @@ v would be associated with foo, and S with bar.  Bundling of short options
 that use '@' as part of their template is not allowed due to the obvious 
 guaranteed problems which will result.
 
+=head1 TEMPLATES
+
+There are a few convenience templates available to code down on code
+generation.  These are not exported by default, however, so you'll need
+explicitly import the ones you want or import them with the B<:all> tag.
+
+=head2 PA_DEBUG
+
+    {
+        Short      => 'D',
+        Long       => 'debug',
+        CountShort => 1,
+    };
+
+=head2 PA_VERBOSE
+
+    {
+        Short      => 'v',
+        Long       => 'verbose',
+        CountShort => 1,
+     };
+
+=head2 PA_HELP
+
+    {
+        Short => 'h',
+        Long  => 'help',
+    };
+
+=head2 PA_VERSION
+
+    {
+        Short => 'V',
+        Long  => 'version',
+    };
+
 =head1 DEPENDENCIES
 
 =over
@@ -1251,16 +1388,11 @@ L<Paranoid::Debug>
       {
         Short       => 'v',
         Long        => 'verbose',
-        Multiple    => 1,
         CountShort  => 1,
-        CanBundle   => 1,
-        Template    => '$',
       },
       {
         Short       => 'f',
         Long        => 'force',
-        CanBundle   => 1,
-        Template    => '',
       },
       {
         Short       => 'h',
@@ -1272,7 +1404,7 @@ L<Paranoid::Debug>
     );
 
   # Process @ARGV:  -vvvfh host1 file1 file2 file3
-  if (parseArgs(@otemplates, %opts, @errors)) {
+  if (parseArgs(@templates, %opts )) {
     setVerbosity($opts{'verbose'});
 
     if ($opts{'force'}) {
@@ -1304,8 +1436,22 @@ Arthur Corliss (corliss@digitalmages.com)
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is licensed under the same terms as Perl, itself. 
-Please see http://dev.perl.org/licenses/ for more information.
+This software is free software.  Similar to Perl, you can redistribute it
+and/or modify it under the terms of either:
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+  a)     the GNU General Public License
+         <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+         Free Software Foundation <http://www.fsf.org/>; either version 1
+         <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+         <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+  b)     the Artistic License 2.0
+         <https://opensource.org/licenses/Artistic-2.0>,
+
+subject to the following additional term:  No trademark rights to
+"Paranoid" have been or are conveyed under any of the above licenses.
+However, "Paranoid" may be used fairly to describe this unmodified
+software, in good faith, but not as a trademark.
+
+(c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+(tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 
