@@ -1,11 +1,25 @@
 # Paranoid::Filesystem -- Filesystem support for paranoid programs
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# $Id: lib/Paranoid/Filesystem.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 #
-# $Id: lib/Paranoid/Filesystem.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+# This software is free software.  Similar to Perl, you can redistribute it
+# and/or modify it under the terms of either:
 #
-#    This software is licensed under the same terms as Perl, itself.
-#    Please see http://dev.perl.org/licenses/ for more information.
+#   a)     the GNU General Public License
+#          <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+#          Free Software Foundation <http://www.fsf.org/>; either version 1
+#          <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+#          <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+#   b)     the "Artistic License 2.0
+#          <https://opensource.org/licenses/Artistic-2.0>",
+#
+# subject to the following additional term:  No trademark rights to
+# "Paranoid" have been or are conveyed under any of the above licenses.
+# However, "Paranoid" may be used fairly to describe this unmodified
+# software, in good faith, but not as a trademark.
+#
+# (c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+# (tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 #
 #####################################################################
 
@@ -33,7 +47,7 @@ use Paranoid::Input;
 use Paranoid::IO;
 use Paranoid::Glob;
 
-($VERSION) = ( q$Revision: 2.03 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.08 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT = qw(
     preadDir     psubdirs    pfiles
@@ -69,7 +83,7 @@ sub pmkdir ($;$\%) {
     my $path = shift;
     my $mode = shift;
     my $eref = shift || {};
-    my ( $dirs, $directory, @parts, $i );
+    my ( $dirs, $directory, $subdir, @parts, $i );
     my $rv = 1;
 
     pdebug( 'entering w/(%s)(%s)', PDLEVEL1, $path, $mode );
@@ -88,7 +102,7 @@ sub pmkdir ($;$\%) {
 
     # Set and detaint mode
     if ($rv) {
-        $mode = umask ^ PERMMASK unless defined $mode;
+        $mode = ptranslatePerms( defined $mode ? $mode : umask ^ PERMMASK );
         unless ( detaint( $mode, 'int' ) ) {
             Paranoid::ERROR =
                 pdebug( 'invalid mode argument passed', PDLEVEL1 );
@@ -112,13 +126,21 @@ sub pmkdir ($;$\%) {
             $i = $parts[0] eq '' ? 1 : 0;
             $i++ while $i < $#parts and -d join '/', @parts[ 0 .. $i ];
             while ( $i <= $#parts ) {
-                unless ( mkdir join( '/', @parts[ 0 .. $i ] ), $mode ) {
+                $subdir = join '/', @parts[ 0 .. $i ];
+                unless ( -d $subdir ) {
+                    if ( mkdir $subdir, $mode ) {
 
-                    # Error out and halt all work
-                    Paranoid::ERROR = pdebug( 'failed to create %s: %s',
-                        PDLEVEL1, $directory, $! );
-                    $rv = 0;
-                    last;
+                        # Make sure perms are applied
+                        chmod $mode, $subdir;
+
+                    } else {
+
+                        # Error out and halt all work
+                        Paranoid::ERROR = pdebug( 'failed to create %s: %s',
+                            PDLEVEL1, $subdir, $! );
+                        $rv = 0;
+                        last;
+                    }
                 }
                 $i++;
             }
@@ -657,7 +679,26 @@ sub ptranslatePerms {
     pIn();
 
     # Validate permissions string
-    if ( defined $perm and $perm =~ /^([ugo]+)([+\-])([rwxst]+)$/s ) {
+    if ( defined $perm and $perm =~ /^\d+$/s ) {
+
+        if ( $perm =~ /^0/s ) {
+            if ( $perm =~ /^0[0-8]{3,4}$/s ) {
+
+                # String representation of octal number
+                eval "\$perm = $perm;";
+                detaint( $perm, 'int', $p );
+
+            } else {
+                pdebug( 'invalid octal presentation: %s', PDLEVEL1, $perm );
+            }
+
+        } else {
+
+            # Probably a converted integer already, treat it as verbatim
+            detaint( $perm, 'int', $p );
+        }
+
+    } elsif ( defined $perm and $perm =~ /^([ugo]+)([+\-])([rwxst]+)$/s ) {
 
         # Translate symbolic representation
         $o = $p = 00;
@@ -678,6 +719,7 @@ sub ptranslatePerms {
         # Report invalid characters in permission string
         Paranoid::ERROR =
             pdebug( 'invalid permissions (%s)', PDLEVEL1, $perm );
+
     }
     $rv = $p;
 
@@ -725,9 +767,15 @@ sub pchmod ($$;\%) {
     $rv = 0 unless defined $glob;
 
     # Convert perms if they're symbolic
-    $ptrans = ptranslatePerms($perms);
-    if ( defined $ptrans ) {
-        $addPerms = $perms =~ /-/s ? 0 : 1;
+    if ( defined $perms and defined( $ptrans = ptranslatePerms($perms) ) ) {
+        if ( $perms =~ /[ugo]+[+-]/si ) {
+            $addPerms = $perms =~ /-/s ? 0 : 1;
+        } else {
+            $ptrans = undef;
+        }
+    } else {
+        pdebug( 'invalid permissions passed: %s', PDLEVEL1, $perms );
+        $rv = 0;
     }
 
     if ($rv) {
@@ -1035,7 +1083,7 @@ Paranoid::Filesystem - Filesystem Functions
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Filesystem.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+$Id: lib/Paranoid/Filesystem.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -1071,6 +1119,20 @@ tracing into each function you must set B<PDEBUG> to at least 9.
 B<pcleanPath>, B<ptranslateLink>, and B<ptranslatePerms> are only exported 
 if this module is used with the B<:all> target.
 
+=head1 IMPORT LISTS
+
+This module exports the following symbols by default:
+
+    preadDir psubdirs pfiles pmkdir prm prmR ptouch
+    ptouchR pchmod pchmodR pchown pchownR pwhich
+
+The following specialized import lists also exist:
+
+    List        Members
+    --------------------------------------------------------
+    all         @defaults ptranslateLink pcleanPath 
+                ptranslatePerms
+
 =head1 SUBROUTINES/METHODS
 
 =head2 pmkdir
@@ -1114,7 +1176,7 @@ that's not present is not considered a failure.
   $rv = prmR("/foo", 1, %errors);
 
 This function works the same as B<prm> but performs a recursive delete,
-similar to "rm -r" on the command line.  An optional second argument determins
+similar to "rm -r" on the command line.  An optional second argument determines
 if symbolic links are followed and the targets also recursively deleted.
 
 =head2 preadDir
@@ -1244,6 +1306,11 @@ B<EXAMPLES>
   $perms = (stat "./bar")[2];
   chmod $perms ^ ptranslatePerms("o-rwx"), "./bar";
 
+B<NOTE:> If this function is called with a numeric representation of
+permissions, it will return them as-is.  This allows for this function to be
+called indiscriminately where you might be given permissions in either format,
+but ultimately want them only in numeric presentation.
+
 =head2 pchmod
 
   $rv = pchmod("/foo", $perms);
@@ -1386,8 +1453,22 @@ Arthur Corliss (corliss@digitalmages.com)
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is licensed under the same terms as Perl, itself. 
-Please see http://dev.perl.org/licenses/ for more information.
+This software is free software.  Similar to Perl, you can redistribute it
+and/or modify it under the terms of either:
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+  a)     the GNU General Public License
+         <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+         Free Software Foundation <http://www.fsf.org/>; either version 1
+         <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+         <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+  b)     the Artistic License 2.0
+         <https://opensource.org/licenses/Artistic-2.0>,
+
+subject to the following additional term:  No trademark rights to
+"Paranoid" have been or are conveyed under any of the above licenses.
+However, "Paranoid" may be used fairly to describe this unmodified
+software, in good faith, but not as a trademark.
+
+(c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+(tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 
