@@ -1,11 +1,25 @@
 # Paranoid::IO::Line -- Paranoid Line-based I/O functions
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# $Id: lib/Paranoid/IO/Line.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 #
-# $Id: lib/Paranoid/IO/Line.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+# This software is free software.  Similar to Perl, you can redistribute it
+# and/or modify it under the terms of either:
 #
-#    This software is licensed under the same terms as Perl, itself.
-#    Please see http://dev.perl.org/licenses/ for more information.
+#   a)     the GNU General Public License
+#          <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+#          Free Software Foundation <http://www.fsf.org/>; either version 1
+#          <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+#          <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+#   b)     the Artistic License 2.0
+#          <https://opensource.org/licenses/Artistic-2.0>,
+#
+# subject to the following additional term:  No trademark rights to
+# "Paranoid" have been or are conveyed under any of the above licenses.
+# However, "Paranoid" may be used fairly to describe this unmodified
+# software, in good faith, but not as a trademark.
+#
+# (c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+# (tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 #
 #####################################################################
 
@@ -29,7 +43,7 @@ use Paranoid::Debug qw(:all);
 use Paranoid::IO qw(:all);
 use Paranoid::Input qw(:all);
 
-($VERSION) = ( q$Revision: 2.03 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.08 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT      = qw(sip nlsip tailf nltailf slurp nlslurp piolClose);
 @EXPORT_OK   = ( @EXPORT, qw(PIOMAXLNSIZE) );
@@ -470,7 +484,7 @@ Paranoid::IO::Line - Paranoid Line-based I/O functions
 
 =head1 VERSION
 
-$Id: lib/Paranoid/IO/Line.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+$Id: lib/Paranoid/IO/Line.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -520,6 +534,18 @@ with a record separator (new line sequence).
 As with all L<Paranoid> modules string descriptions of errors can be retrieved
 from L<Paranoid::ERROR> as they occur.
 
+=head1 IMPORT LISTS
+
+This module exports the following symbols by default:
+
+    sip nlsip tailf nltailf slurp nlslurp piolClose
+
+The following specialized import lists also exist:
+
+    List        Members
+    --------------------------------------------------------
+    all         @defaults PIOMAXLNSIZE
+
 =head1 SUBROUTINES/METHODS
 
 =head2 PIOMAXLNSIZE
@@ -571,6 +597,9 @@ B<NOTE:> I<sip> does try to check the file stat with every call.  This allows
 us to automatically flush buffers and reopen files in the event that the file
 you're sipping from was truncated, deleted, or overwritten.
 
+The third argument is a boolean option which controls whether lines are
+automatically chomped or not.  It defaults to not.
+
 =head2 nlsip
 
     $nlines = nlsip($filename, @lines);
@@ -619,6 +648,9 @@ Files with slurp are explicitly closed after the read.  All the normal
 safeguards apply:  I<PIOMAXFSIZE> is the largest amount of data that will be
 read into memory, and all lines must be within I<PIOMAXLNSIZE>.
 
+The third argument is a boolean option which controls whether lines are
+automatically chomped or not.  It defaults to not.
+
 =head2 nlslurp
 
   $nlines = nlslurp($filename, @lines);
@@ -678,8 +710,22 @@ Arthur Corliss (corliss@digitalmages.com)
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is licensed under the same terms as Perl, itself. 
-Please see http://dev.perl.org/licenses/ for more information.
+This software is free software.  Similar to Perl, you can redistribute it
+and/or modify it under the terms of either:
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+  a)     the GNU General Public License
+         <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+         Free Software Foundation <http://www.fsf.org/>; either version 1
+         <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+         <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+  b)     the Artistic License 2.0
+         <https://opensource.org/licenses/Artistic-2.0>,
+
+subject to the following additional term:  No trademark rights to
+"Paranoid" have been or are conveyed under any of the above licenses.
+However, "Paranoid" may be used fairly to describe this unmodified
+software, in good faith, but not as a trademark.
+
+(c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+(tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 
