@@ -1,11 +1,25 @@
 # Paranoid::Network -- Network functions for paranoid programs
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# $Id: lib/Paranoid/Network.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 #
-# $Id: lib/Paranoid/Network.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+# This software is free software.  Similar to Perl, you can redistribute it
+# and/or modify it under the terms of either:
 #
-#    This software is licensed under the same terms as Perl, itself.
-#    Please see http://dev.perl.org/licenses/ for more information.
+#   a)     the GNU General Public License
+#          <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+#          Free Software Foundation <http://www.fsf.org/>; either version 1
+#          <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+#          <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+#   b)     the Artistic License 2.0
+#          <https://opensource.org/licenses/Artistic-2.0>,
+#
+# subject to the following additional term:  No trademark rights to
+# "Paranoid" have been or are conveyed under any of the above licenses.
+# However, "Paranoid" may be used fairly to describe this unmodified
+# software, in good faith, but not as a trademark.
+#
+# (c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+# (tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 #
 #####################################################################
 
@@ -29,7 +43,7 @@ use Paranoid::Network::Socket;
 use Paranoid::Network::IPv4 qw(:all);
 use Paranoid::Network::IPv6 qw(:all);
 
-($VERSION) = ( q$Revision: 2.03 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.08 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT      = qw(ipInNetworks hostInDomains extractIPs netIntersect);
 @EXPORT_OK   = ( @EXPORT, qw(NETMATCH HOSTNAME_REGEX) );
@@ -267,7 +281,7 @@ Paranoid::Network - Network functions for paranoid programs
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Network.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+$Id: lib/Paranoid/Network.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -289,6 +303,18 @@ caveats.  Please consult L<Paranoid::Network::Socket> for more details.
 
 I<NETMATCH> and I<HOSTNAME_REGEX> are not exported by default.
 
+=head1 IMPORT LISTS
+
+This module exports the following symbols by default:
+
+    ipInNetworks hostInDomains extractIPs netIntersect
+
+The following specialized import lists also exist:
+
+    List        Members
+    --------------------------------------------------------
+    all         @defaults NETMATCH HOSTNAME_REGEX
+
 =head1 SUBROUTINES/METHODS
 
 =head2 ipInNetworks
@@ -427,8 +453,22 @@ Arthur Corliss (corliss@digitalmages.com)
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is licensed under the same terms as Perl, itself. 
-Please see http://dev.perl.org/licenses/ for more information.
+This software is free software.  Similar to Perl, you can redistribute it
+and/or modify it under the terms of either:
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+  a)     the GNU General Public License
+         <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+         Free Software Foundation <http://www.fsf.org/>; either version 1
+         <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+         <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+  b)     the Artistic License 2.0
+         <https://opensource.org/licenses/Artistic-2.0>,
+
+subject to the following additional term:  No trademark rights to
+"Paranoid" have been or are conveyed under any of the above licenses.
+However, "Paranoid" may be used fairly to describe this unmodified
+software, in good faith, but not as a trademark.
+
+(c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+(tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 
