@@ -1,11 +1,25 @@
 # Paranoid::Process -- Process management support for paranoid programs
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# $Id: lib/Paranoid/Process.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 #
-# $Id: lib/Paranoid/Process.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+# This software is free software.  Similar to Perl, you can redistribute it
+# and/or modify it under the terms of either:
 #
-#    This software is licensed under the same terms as Perl, itself.
-#    Please see http://dev.perl.org/licenses/ for more information.
+#   a)     the GNU General Public License
+#          <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+#          Free Software Foundation <http://www.fsf.org/>; either version 1
+#          <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+#          <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+#   b)     the Artistic License 2.0
+#          <https://opensource.org/licenses/Artistic-2.0>,
+#
+# subject to the following additional term:  No trademark rights to
+# "Paranoid" have been or are conveyed under any of the above licenses.
+# However, "Paranoid" may be used fairly to describe this unmodified
+# software, in good faith, but not as a trademark.
+#
+# (c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+# (tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 #
 #####################################################################
 
@@ -28,20 +42,24 @@ use Paranoid::Debug qw(:all);
 use POSIX qw(getuid setuid setgid WNOHANG setsid);
 use Carp;
 
-($VERSION) = ( q$Revision: 2.03 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.08 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT    = qw(switchUser daemonize);
 @EXPORT_OK = (
     @EXPORT, qw(MAXCHILDREN childrenCount installChldHandler
-        sigchld pfork ptranslateUser ptranslateGroup pcapture
+        sigchld pfork pcommFork ptranslateUser ptranslateGroup pcapture
+        installSIGH uninstallSIGH installSIGD uninstallSIGD
         ) );
 %EXPORT_TAGS = (
     all   => [@EXPORT_OK],
+    misc  => [qw(pcapture)],
     pfork => [
         qw(MAXCHILDREN childrenCount installChldHandler
-            sigchld pfork daemonize)
+            sigchld pfork pcommFork daemonize)
         ],
-        );
+    signal => [qw(installSIGH uninstallSIGH installSIGD uninstallSIGD)],
+    user   => [qw(switchUser ptranslateUser ptranslateGroup)],
+    );
 
 #####################################################################
 #
@@ -49,9 +67,143 @@ use Carp;
 #
 #####################################################################
 
+{
+    my %signals = ( map { $_ => [] } keys %SIG );
+    my %original = %SIG;
+
+    sub _sigHandler {
+
+        # Purpose:  Runs all code refs assigned to the signal
+        # Returns:  Boolean
+        # Usage:    _sigHandler($signal);
+
+        my ( $signal, @sargs ) = @_;
+        my $sref;
+
+        local $SIG{$signal} = 'IGNORE';
+        foreach $sref ( @{ $signals{$signal} } ) {
+            &$sref( $signal, @sargs );
+        }
+
+        return 1;
+    }
+
+    sub installSIGD {
+
+        # Purpose:  Installs dispatcher for sig handlers that have code refs
+        #           assigned
+        # Returns:  Boolean
+        # Usage:    $rv = installSIGD();
+
+        my $sig;
+
+        pdebug( 'entering', PDLEVEL1 );
+        pIn();
+
+        foreach $sig ( keys %signals ) {
+            $SIG{$sig} = \&_sigHandler if scalar @{ $signals{$sig} };
+        }
+
+        pOut();
+        pdebug( 'leaving w/rv: 1', PDLEVEL1 );
+
+        return 1;
+    }
+
+    sub uninstallSIGD {
+
+        # Purpose:  Uninstalls the dispatcher
+        # Returns:  Boolean
+        # Usage:    $rv = uninstallSIGD();
+
+        pdebug( 'entering', PDLEVEL1 );
+        pIn();
+
+        foreach ( keys %original ) {
+            $SIG{$_} = $original{$_}
+                if defined $SIG{$_}
+                    and $SIG{$_} eq \&_sigHandler;
+        }
+
+        pOut();
+        pdebug( 'leaving w/rv: 1', PDLEVEL1 );
+
+        return 1;
+    }
+
+    sub installSIGH ($\&) {
+
+        # Purpose:  Assigns a code ref to a signal array
+        # Returns:  Boolean
+        # Usage:    $rv = installSIGH($signal, $sref);
+
+        my ( $signal, $sref ) = @_;
+        my $rv = 1;
+
+        pdebug( 'entering w/%s, %s', PDLEVEL1, $signal, $sref );
+        pIn();
+
+        if ( exists $signals{$signal} ) {
+            if ( grep { $_ eq $sref } @{ $signals{$signal} } ) {
+                pdebug( '%s handler already installed', PDLEVEL2, $signal );
+            } else {
+                push @{ $signals{$signal} }, $sref;
+                pdebug( '%s handler installed', PDLEVEL2, $signal );
+            }
+        } else {
+            pdebug( 'unknown signal: %s', PDLEVEL1, $signal );
+            $rv = 0;
+        }
+
+        pOut();
+        pdebug( 'leaving w/rv: %s', PDLEVEL1, $rv );
+
+        return $rv;
+    }
+
+    sub uninstallSIGH ($\&) {
+
+        # Purpose:  Removes a code ref for a signal array
+        # Returns:  Boolean
+        # Usage:    $rv = uninstallSIGH($signal, $sref);
+
+        my ( $signal, $sref ) = @_;
+        my $rv = 1;
+        my ( $sigh, $i );
+
+        pdebug( 'entering w/%s, %s', PDLEVEL1, $signal, $sref );
+        pIn();
+
+        if ( exists $signals{$signal} ) {
+            if ( grep { $_ eq $sref } @{ $signals{$signal} } ) {
+                $i = 0;
+                foreach $sigh ( @{ $signals{$signal} } ) {
+                    if ( $sigh eq $sref ) {
+                        splice @{ $signals{$signal} }, $i, 1;
+                        last;
+                    }
+                    $i++;
+                }
+                pdebug( '%s handler removed', PDLEVEL2, $signal );
+            } else {
+                pdebug( 'no %s handler to remove', PDLEVEL2, $signal );
+            }
+        } else {
+            pdebug( 'unknown signal: %s', PDLEVEL1, $signal );
+            $rv = 0;
+        }
+
+        pOut();
+        pdebug( 'leaving w/rv: %s', PDLEVEL1, $rv );
+
+        return $rv;
+    }
+}
+
 {
     my $maxChildren = 0;
     my $numChildren = 0;
+    my @forkedPIDs  = ();
     my $chldRef     = undef;
 
     sub MAXCHILDREN : lvalue {
@@ -67,6 +219,11 @@ use Carp;
     sub _incrChildren { $numChildren++ }
     sub _decrChildren { $numChildren-- }
 
+    sub _resetChildren {
+        @forkedPIDs  = ();
+        $numChildren = 0;
+    }
+
     sub installChldHandler (\&) {
 
         # Purpose:  Installs a code reference to execute whenever a child
@@ -79,6 +236,19 @@ use Carp;
         return 1;
     }
     sub _chldHandler { return $chldRef }
+
+    sub _addPID { push @forkedPIDs, shift }
+
+    sub _grepPID {
+        my $pid = shift;
+        return scalar grep { $_ == $pid } @forkedPIDs;
+    }
+
+    sub _delPID {
+        my $pid = shift;
+        @forkedPIDs = grep { $_ != $pid } @forkedPIDs;
+        return 1;
+    }
 }
 
 sub sigchld {
@@ -87,28 +257,26 @@ sub sigchld {
     # Returns:  True (1)
     # Usage:    $SIG{CHLD} = \&sigchld;
 
-    my ( $osref, $pid );
+    my ($pid);
     my $sref = _chldHandler();
 
     # Remove the signal handler so we're not preempted
-    $osref = $SIG{CHLD};
-    $SIG{CHLD} = sub {1};
+    local $SIG{CHLD} = sub {1};
 
     # Process children exit values
     do {
         $pid = waitpid -1, WNOHANG;
-        if ( $pid > 0 ) {
+        if ( $pid > 0 and _grepPID($pid) ) {
             _decrChildren();
+            _delPID($pid);
             pdebug( 'child %d reaped w/rv: %s', PDLEVEL1, $pid, $? );
+            pdebug( 'children remaining: %s', PDLEVEL1, childrenCount() );
 
             # Call the user's sig handler if defined
             &$sref( $pid, $? ) if defined $sref;
         }
     } until $pid < 1;
 
-    # Reinstall the signal handler
-    $SIG{CHLD} = $osref;
-
     return 1;
 }
 
@@ -174,7 +342,66 @@ sub pfork {
 
     # Fork and return
     $rv = fork;
-    _incrChildren() if defined $rv;
+    if ( defined $rv ) {
+        if ( $rv > 0 ) {
+            _incrChildren();
+            _addPID($rv);
+        } else {
+            _resetChildren();
+        }
+    }
+
+    pOut();
+    pdebug( 'leaving w/rv: %s', PDLEVEL1, $rv );
+
+    return $rv;
+}
+
+sub pcommFork (\$\$) {
+
+    # Purpose:  Creates pipes for bi-directional communiation, then calls
+    #           pfork()
+    # Returns:  Return value of children handler if installed, otherwise
+    #           undef.
+    # Usage:    $rv = pcommFork($procr, $procw);
+
+    my ( $procr, $procw ) = @_;
+    my ( $tp, $fp, $tc, $fc, $sfd, $rv );
+
+    pdebug( 'entering', PDLEVEL1 );
+    pIn();
+
+    if ( pipe( $fc, $tp ) and pipe( $fp, $tc ) ) {
+        $sfd = select $tc;
+        $|   = 1;
+        select $tp;
+        $| = 1;
+        select $sfd;
+
+        $rv = pfork();
+        if ( defined $rv ) {
+            if ($rv) {
+                close $tp;
+                close $fp;
+                $$procw = $tc;
+                $$procr = $fc;
+            } else {
+                close $tc;
+                close $fc;
+                $$procw = $tp;
+                $$procr = $fp;
+            }
+        } else {
+            $$procr = undef;
+            $$procw = undef;
+            close $tp;
+            close $fp;
+            close $tc;
+            close $fc;
+        }
+    } else {
+        pdebug( 'failed to create pipes: %s', PDLEVEL1, $! );
+    }
 
     pOut();
     pdebug( 'leaving w/rv: %s', PDLEVEL1, $rv );
@@ -393,11 +620,11 @@ Paranoid::Process - Process Management Functions
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Process.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+$Id: lib/Paranoid/Process.pm, 2.08 2020/12/31 12:10:06 acorliss Exp $
 
 =head1 SYNOPSIS
 
-  use Paranoid::Process;
+  use Paranoid::Process qw(:all);
 
   $rv = daemonize();
 
@@ -407,6 +634,7 @@ $Id: lib/Paranoid/Process.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
   $count = childrenCount();
   installChldHandler(&cleanup);
   $rv = pfork();
+  $rv = pcommFork($rh, $wh);
 
   $uid = ptranslateUser("foo");
   $gid = ptranslateGroup("foo");
@@ -414,16 +642,54 @@ $Id: lib/Paranoid/Process.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
 
   $rv = pcapture($cmd, $crv, $out);
 
+  installSIGH('INT', &sigint1):
+  installSIGH('INT', &sigint2):
+  installSIGH('INT', &sigint3):
+
+  uninstallSIGH('INT', &sigint2);
+
+  installSIGD();
+  uninstallSIGD();
+
 =head1 DESCRIPTION
 
 This module provides a few functions meant to make life easier when managing
-processes.  The following export targets are provided:
+processes.
 
-  all               All functions within this module
-  pfork             All child management functions
+=head1 IMPORT LISTS
 
-Only the functions B<switchUser> and B<daemonize> are currently exported by 
-default.
+This module exports the following symbols by default:
+
+    switchUser daemonize
+
+The following specialized import lists also exist:
+
+    List        Members
+    --------------------------------------------------------
+    misc        pcapture
+    pfork       MAXCHILDREN childrenCount installChldHandler
+                sigchld pfork pcommFork daemonize
+    signal      installSIGH uninstallSIGH installSIGD 
+                uninstallSIGD
+    user        switchUser ptranslateUser ptranslateGroup
+    all         @misc @pfork @signal @user
+
+=head1 IMPORT LISTS
+
+This module exports the following symbols by default:
+
+    switchUser daemonize
+
+The following specialized import lists also exist:
+
+    List        Members
+    --------------------------------------------------------
+    pfork       MAXCHILDREN childrenCount installChldHandler
+                sigchld pfork pcommFork daemonize
+    signal      installSIGH uninstallSIGH installSIGD 
+                uninstallSIGD
+    user        switchUser ptranslateUser ptranslateGroup
+    misc        pcapture
 
 =head1 SUBROUTINES/METHODS
 
@@ -434,6 +700,11 @@ forked at a time by B<pfork>.  The default is zero, which allows unlimited
 children.  Once the limit is met pfork becomes a blocking call until a child 
 exits so the new one can be spawned.
 
+B<NOTE:> This limit on children is enforced on a per-process basis.  That
+means that while a process is limited to the max threshold, its children
+could also fork their own batch of children as well, up to whatever max is set
+in those processes.
+
 =head2 childrenCount
 
   $count = childrenCount();
@@ -445,13 +716,17 @@ This function returns the current number of children spawned by B<pfork>.
   installChldHandler(&cleanup);
 
 This function takes a reference to a subroutine.  If used the subroutine will
-be called every time a child exits.  That subroutine will be called with the
-child's PID and exit value as arguments.
+be called every time a child exits and triggers L<sigchild>.  That subroutine 
+will be called with the child's PID and exit value as arguments.
 
 =head2 sigchld
 
   $SIG{CHLD} = \&sigchld;
 
+  # Or, if using the signal dispatcher
+  installSIGH('CHLD', &sigchld);
+  installSIGD();
+
 This function decrements the child counter necessary for pfork's operation, as
 well as calling the user's signal handler with each child's PID and exit
 value.
@@ -474,6 +749,18 @@ advantage of a blocking fork call that respects the MAXCHILDREN limit.  Use of
 this function, however, also assumes the use of B<sigchld> as the signal
 handler for SIGCHLD.
 
+=head2 pcommFork
+
+    $rv = pcommFork($rh, $wh);
+
+This function extends B<pfork> by automatically setting up bidirectional pipes
+for interprocess communication.  The two scalars passed as arguments will have
+the appropriate ends of the pipe returned to both the parent and the child.
+
+In the event that a fork fails, B<undef> will be assigned to both scalars.
+
+The return value will be the result of the B<fork> call.
+
 =head2 ptranslateUser
 
   $uid = ptranslateUser("foo");
@@ -490,13 +777,12 @@ by B<getgrent>.  If no match is found it returns undef.
 
 =head2 switchUser
 
+  $rv = switchUser($user);
   $rv = switchUser($user, $group);
 
 This function can be fed one or two arguments, both either named user or
 group, or UID or GID.  Both user and group arguments are optional as long as
-the other is called.  In other words, you can pass undef for one of the
-arguments, but not for both.  If you're only switching the user you can pass
-only the user argument.
+one of them is defined.
 
 =head2 pcapture
 
@@ -524,6 +810,35 @@ know ahead of time what kind of convoluted arguments you might be handing this
 call before system is called.  Failing to detaint that argument will cause
 your script to exit under taint mode.
 
+=head2 installSIGH
+
+  installSIGH($signal, &subroutine);
+
+This installs another subroutine in the queue for the specified signal.
+Subroutines are called in the order that they're added to the queue.  Adding
+a specific subroutine more than once is filtered out so each subroutine in the
+queue is unique.
+
+=head2 uninstallSIGH
+
+  uninstallSIGH($signal, &subroutine);
+
+Removes a subroutine from the specified queue.
+
+=head2 installSIGD
+
+  installSIGD();
+
+Inserts the dispatcher for each signal with subroutines in the queue.
+
+=head2 uninstallSIGD
+
+  uninstallSIGD();
+
+Removes the dispatcher for each signal that's using the dispatcher.  The
+signal handler installed is what ever was set when this module's code was
+loaded and initialized.
+
 =head1 DEPENDENCIES
 
 =over
@@ -586,11 +901,6 @@ For instance, to track the children's history in the parent:
 
 =head1 BUGS AND LIMITATIONS
 
-There's a bug in an current versions of Perl where B<ptranslateGroup> can 
-return negative numbers instead the actual GID.  This is due to the platform
-supporting unsigned integers for the GID, but Perl was casting it as a signed
-integer.  A patch has been submitted to blead-perl.
-
 On Solaris B<pcapture> doesn't return a -1 for non-existant commands, but a 0.
 On Linux this appears to work as intended.
 
@@ -600,8 +910,22 @@ Arthur Corliss (corliss@digitalmages.com)
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is licensed under the same terms as Perl, itself. 
-Please see http://dev.perl.org/licenses/ for more information.
+This software is free software.  Similar to Perl, you can redistribute it
+and/or modify it under the terms of either:
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+  a)     the GNU General Public License
+         <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+         Free Software Foundation <http://www.fsf.org/>; either version 1
+         <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+         <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+  b)     the Artistic License 2.0
+         <https://opensource.org/licenses/Artistic-2.0>,
+
+subject to the following additional term:  No trademark rights to
+"Paranoid" have been or are conveyed under any of the above licenses.
+However, "Paranoid" may be used fairly to describe this unmodified
+software, in good faith, but not as a trademark.
+
+(c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+(tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 
